@@ -246,11 +246,11 @@ def reset_workspace(user_session, workspace):
     splits_api.delete_all_splits(workspace["id"])
     segments_api.delete_all_segments(workspace["id"])
 
-    traffic_types = traffic_types_api.list_traffic_types(workspace["id"])
-    # Internal again
-    for traffic_type in traffic_types:
-        if traffic_type['name'] != 'user':
-            traffictypes_internal.delete_traffic_type(user_session, traffic_type['id'])
+    # traffic_types = traffic_types_api.list_traffic_types(workspace["id"])
+    # # Internal again
+    # for traffic_type in traffic_types:
+    #     if traffic_type['name'] != 'user':
+    #         traffictypes_internal.delete_traffic_type(user_session, traffic_type['id'])
 
 def create_org_onboarding():
     menu.success_message("Creating Onboarding Organization")
@@ -268,8 +268,8 @@ def create_org_onboarding():
     reset_workspace(user_session, workspace)
 
     sdk_token = login_internal.sdk_token(user_session, org_id)
-    onboarding_1(user_session, user_id, org_id, sdk_token, workspace)
-    onboarding_2(user_session, user_id, org_id, sdk_token, workspace)
+    experiment_sign_up(user_session, user_id, org_id, sdk_token, workspace)
+    experiment_live_tail(user_session, user_id, org_id, sdk_token, workspace)
 
     # Return scope to base_user
     user.set_user(previous_user)
@@ -278,7 +278,7 @@ def create_org_onboarding():
 
 
 def update_org():
-    user_email = "workshop+demoorg-20210409-aXPWt@split.io"
+    user_email = "workshop+demoorg-20210415-rkxyH@split.io"
     password = "Test_1234"
 
     result = get_demo_org(user_email)
@@ -288,27 +288,27 @@ def update_org():
 
     menu.success_message("Logging in as User")
     user_session = login_internal.login(user_email,password)
-
-    reset_metrics(user_session, org_id)
     previous_user = connect_admin(user_session, org_id)
+    sdk_token = login_internal.sdk_token(user_session, org_id)
 
     workspace = workspaces_api.get_workspace("Default")
-    reset_workspace(user_session, workspace)
 
-    sdk_token = login_internal.sdk_token(user_session, org_id)
-    onboarding_1(user_session, user_id, org_id, sdk_token, workspace)
-    onboarding_2(user_session, user_id, org_id, sdk_token, workspace)
+    # reset_metrics(user_session, org_id)
+    # reset_workspace(user_session, workspace)
+    # experiment_sign_up(user_session, user_id, org_id, sdk_token, workspace)
+    # experiment_live_tail(user_session, user_id, org_id, sdk_token, workspace)
+    experiment_data_export(user_session, user_id, org_id, sdk_token, workspace)
 
     # Return scope to base_user
     user.set_user(previous_user)
 
     menu.success_message("Updated")
 
-def onboarding_1(user_session, user_id, org_id, sdk_token, workspace):
-    menu.success_message("Creating Onboarding 1")
+def experiment_sign_up(user_session, user_id, org_id, sdk_token, workspace):
+    menu.success_message("Creating Sign Up Experiment")
 
     # Create Dedicated Traffic Type
-    traffic_type_name = "user_1"
+    traffic_type_name = "visitor"
     traffictypes_internal.create_traffic_type(user_session, org_id, workspace["id"], traffic_type_name)
 
     # Create and ramp onboarding
@@ -320,24 +320,122 @@ def onboarding_1(user_session, user_id, org_id, sdk_token, workspace):
     menu.success_message("Running Experiment")
     experiment = Experiment(sdk_token, split_name, traffic_type=traffic_type_name)
     experiment.register("sign_up").probability(.1834,1,.22)
-    experiment.run(5000)
+    experiment.run(3258)
 
     # Create metrics
     menu.success_message("Creating Metrics")
     traffic_type = traffic_types_api.get_traffic_type(workspace["id"], traffic_type_name)
     metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Sign Up Rate", "sign_up", "RATE")
 
-def onboarding_2(user_session, user_id, org_id, sdk_token, workspace):
-    menu.success_message("Creating Onboarding 2")
+def experiment_live_tail(user_session, user_id, org_id, sdk_token, workspace):
+    menu.success_message("Creating Live Tail Experiment")
 
     # Create Dedicated Traffic Type
-    traffic_type_name = "user_2"
+    traffic_type_name = "user"
+    # traffictypes_internal.create_traffic_type(user_session, org_id, workspace["id"], traffic_type_name)
+
+    # TODO: Create Employees segment
+    # TODO: Add employees entries
+    # TODO: Add employees experiment data
+
+    # Create and ramp early version
+    split_name = "live_tail"
+    split_selectors.create_split_operator(workspace["id"], traffic_type_name, split_name)
+    definition_selectors.target_segments_operator(workspace["id"], "Prod-Default", split_name, "on", ["employees"])
+    definition_selectors.ramp_split_operator(workspace["id"], "Prod-Default", split_name, ramp_percent=25)
+
+    # Run Experiment
+    menu.success_message("Running Experiment")
+    experiment = Experiment(sdk_token, split_name, traffic_type=traffic_type_name)
+    experiment.register("live_tail.start").count(delta=.08023,p_value=.5472,mean=8)
+    experiment.register("live_tail.time").total(.0443213,0.915853,85453)
+    experiment.register("redis.latency").average(.07592,0.363409,187.324)
+    experiment.run(1945)
+
+    # Create metrics
+    menu.success_message("Creating Metrics")
+    traffic_type = traffic_types_api.get_traffic_type(workspace["id"], traffic_type_name)
+    metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Live Tail Query Starts", "live_tail.start", "COUNT")
+    metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Active Live Tail Time", "live_tail.time", "TOTAL")
+    metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Redis Transaction Latency", "redis.latency", "AVERAGE", is_positive=False)
+
+    # Create and ramp data hub after data collected
+    split_name = "live_tail-later"
+    split_selectors.create_split_operator(workspace["id"], traffic_type_name, split_name)
+    definition_selectors.target_segments_operator(workspace["id"], "Prod-Default", split_name, "on", ["employees"])
+    definition_selectors.ramp_split_operator(workspace["id"], "Prod-Default", split_name, ramp_percent=25)
+
+    # Run Experiment
+    menu.success_message("Running Experiment")
+    experiment = Experiment(sdk_token, split_name, traffic_type=traffic_type_name)
+    experiment.register("live_tail.start").count(delta=.07462,p_value=.4283,mean=7.5)
+    experiment.register("live_tail.time").total(.05668,0.63,91087)
+    experiment.register("redis.latency").average(.18234,0.000197,201.467)
+    experiment.run(4962)
+
+
+def experiment_data_export(user_session, user_id, org_id, sdk_token, workspace):
+    menu.success_message("Creating Data Export Experiment")
+
+    # Create Dedicated Traffic Type
+    traffic_type_name = "user_1" #"user."
+    traffictypes_internal.create_traffic_type(user_session, org_id, workspace["id"], traffic_type_name)
+
+    # TODO: Create Employees segment
+    # TODO: Add employees entries
+    # TODO: Add employees experiment data
+
+    # Create and ramp early version
+    split_name = "data_export"
+    # split_selectors.create_split_operator(workspace["id"], traffic_type_name, split_name)
+    # definition_selectors.target_segments_operator(workspace["id"], "Prod-Default", split_name, "on", ["employees"])
+    # definition_selectors.ramp_split_operator(workspace["id"], "Prod-Default", split_name, ramp_percent=25)
+
+    # Run Experiment
+    menu.success_message("Running Experiment")
+    experiment = Experiment(sdk_token, split_name, key_pattern="exp_{position}", traffic_type=traffic_type_name, attributes={"entitlements":["experimentation"]})
+    experiment.register("live_tail.start").count(delta=-.0614,p_value=.0481,mean=7.1)
+    experiment.register("live_tail.time").total(-.1521,0.0642,90134)
+    experiment.register("redis.latency").average(-.043142,0.7812,131.324)
+
+    experiment.register("data_export.start", properties={"type": "impressions"}).count(.3142,0.00134,3.4)
+    experiment.register("data_export.start", properties={"type": "events"}).count(0.2841,0.0211,5.1)
+    experiment.run(2248)
+
+    experiment = Experiment(sdk_token, split_name, key_pattern="imp_{position}", traffic_type=traffic_type_name, attributes={"entitlements":[]})
+    experiment.register("live_tail.start").count(delta=-.0442,p_value=.0943,mean=7.2)
+    experiment.register("live_tail.time").total(-.13652,0.1563,90134)
+    experiment.register("redis.latency").average(.03223,0.6248,131.324)
+
+    experiment.register("data_export.start", properties={"type": "impressions"}).count(.3741,0.00015,4.2)
+    experiment.register("data_export.start", properties={"type": "events"}).count(0,1,0)
+    experiment.run(3624)
+    
+
+    # Create metrics
+    # menu.success_message("Creating Metrics")
+    # traffic_type = traffic_types_api.get_traffic_type(workspace["id"], traffic_type_name)
+    # metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Live Tail Query Starts.", "live_tail.start", "COUNT")
+    # metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Active Live Tail Time.", "live_tail.time", "TOTAL")
+    # metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Redis Transaction Latency.", "redis.latency", "AVERAGE", is_positive=False)
+
+    # metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Data Export Starts", "data_export.start", "COUNT")
+    # base_filter = [{ "property": "type", "operator": "STRING_EQUAL", "secondOperand": "impressions", "inverted": False,"numberRangeOperand": None,"stringInListOperand": None }]
+    # metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Data Export Starts - Events", "data_export.start", "COUNT", base_property_filters=base_filter)
+    # base_filter = [{ "property": "type", "operator": "STRING_EQUAL", "secondOperand": "events", "inverted": False,"numberRangeOperand": None,"stringInListOperand": None }]
+    # metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Data Export Starts - Impressions", "data_export.start", "COUNT", base_property_filters=base_filter)
+
+def onboarding_3(user_session, user_id, org_id, sdk_token, workspace):
+    menu.success_message("Creating Onboarding 3")
+
+    # Create Dedicated Traffic Type
+    traffic_type_name = "reader"
     traffictypes_internal.create_traffic_type(user_session, org_id, workspace["id"], traffic_type_name)
 
     # Create and ramp onboarding
     split_name = "metrics_reference"
     split_selectors.create_split_operator(workspace["id"], traffic_type_name, split_name)
-    definition_selectors.ramp_split_operator(workspace["id"], "Prod-Default", split_name, ramp_percent=25)
+    definition_selectors.ramp_split_operator(workspace["id"], "Prod-Default", split_name, ramp_percent=50)
 
     # Run Experiment
     menu.success_message("Running Experiment")
@@ -345,7 +443,7 @@ def onboarding_2(user_session, user_id, org_id, sdk_token, workspace):
     experiment.register("click", properties={ "element": "#btn-create_metric" }).count(delta=.04023,p_value=.5472,mean=8)
     experiment.register("session.ping", properties={ "url": "https://www.split.io/guides/metrics-reference/active-users/" }).total(.32592,0.163409,85453)
     experiment.register("page_load").average(.0443213,0.915853,187.324)
-    experiment.run(2000)
+    experiment.run(1865)
 
     # Create metrics
     menu.success_message("Creating Metrics")
@@ -355,4 +453,4 @@ def onboarding_2(user_session, user_id, org_id, sdk_token, workspace):
     
     base_filter = [{ "property": "url", "operator": "STRING_EQUAL", "secondOperand": ".*/guides/metrics-reference/.*", "inverted": False,"numberRangeOperand": None,"stringInListOperand": None }]
     metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Time in Metric Reference", "session.ping", "TOTAL", base_property_filters=base_filter)
-    metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Average Page Load Time", "page_load", "AVERAGE")
+    metrics_internal.create_metric(user_session, user_id, org_id, workspace["id"], traffic_type["id"], "Average Page Load Time", "page_load", "AVERAGE")
\ No newline at end of file
